#ifndef _FILEIO_STREAM_H
#define _FILEIO_STREAM_H

#include "eca-fileio.h"

class ECA_FILE_IO_STREAM : public ECA_FILE_IO {
  // --
  // Class that provides file-io and buffering functions for 
  // other classes (uses normal file streams).
  // --

 private:

  FILE *f1;
  long int bytes_rep;

  string mode_rep;
   
 public:


  // --
  // Open/close routines
  // ---
  void open_file(const string& fname, 
		 const string& fmode, 
		 bool handle_errors = true);
  void open_stdin(void);
  void open_stdout(void);
  void close_file(void);

  // --
  // Normal file operations
  // ---
  void read_to_buffer(void* obuf, long int bytes);
  void write_from_buffer(void* obuf, long int bytes);

  void set_file_position(long int newpos);
  void set_file_position_advance(long int fw);
  void set_file_position_end(void);
  long int get_file_position(void);
  long int get_file_length(void);

  // --
  // Status
  // ---
  bool is_file_ready(void);
  bool is_file_error(void);
  long int file_bytes_processed(void);
  const string& file_mode(void) { return(mode_rep); }

  ECA_FILE_IO_STREAM (void) { }
};

#endif
